@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2015,2017,2019-2024 Aurimas Cernius
+ * Copyright (C) 2010-2015,2017,2019-2025 Aurimas Cernius
  * Copyright (C) 2009 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -160,11 +160,10 @@ namespace {
     , m_addin_manager(note_manager.get_addin_manager())
     , m_note_manager(note_manager)
   {
-    set_margin(5);
     set_resizable(true);
     set_title(_("Gnote Preferences"));
 
-    get_content_area()->set_spacing(5);
+    get_content_area()->get_parent()->set_margin(5);
 
     Gtk::Notebook *notebook = Gtk::make_managed<Gtk::Notebook>();
     notebook->set_margin(5);
@@ -1213,6 +1212,7 @@ namespace {
   {
     property_destroy_with_parent() = true;
     add_button(_("_Close"), Gtk::ResponseType::CLOSE);
+    set_modal(true);
     
     // TODO: Change this icon to be an addin/package icon
     Gtk::Image *icon = Gtk::make_managed<Gtk::Image>();
