@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2019-2021 Aurimas Cernius
+ * Copyright (C) 2019-2023 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -57,7 +57,7 @@ void GvfsSyncService::post_sync_cleanup()
   unmount_sync();
 }
 
-bool GvfsSyncService::is_supported()
+bool GvfsSyncService::is_supported() const
 {
   return true;
 }
@@ -98,11 +98,6 @@ bool GvfsSyncService::test_sync_directory(const Glib::RefPtr<Gio::File> & path,
         error = _("Failure writing test file");
         return false;
       }
-      Glib::ustring line = sharp::file_read_all_text(test_path);
-      if(line != test_line) {
-        error = _("Failure when checking test file contents");
-        return false;
-      }
 
       // Test ability to delete
       if(!test_path->remove()) {
@@ -113,10 +108,6 @@ bool GvfsSyncService::test_sync_directory(const Glib::RefPtr<Gio::File> & path,
 
     return true;
   }
-  catch(Glib::Exception & e) {
-    error = e.what();
-    return false;
-  }
   catch(std::exception & e) {
     error = e.what();
     return false;
