@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2014,2016-2017,2019,2021,2023 Aurimas Cernius
+ * Copyright (C) 2012-2014,2016-2017,2019,2021,2023-2024 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -82,17 +82,17 @@ namespace sync {
   }
 
 
-  bool NoteUpdate::compare_tags(const std::map<Glib::ustring, Tag::Ptr> set1, const std::map<Glib::ustring, Tag::Ptr> set2) const
+  bool NoteUpdate::compare_tags(const NoteData::TagSet &set1, const NoteData::TagSet &set2) const
   {
     if(set1.size() != set2.size()) {
       return false;
     }
-    for(auto iter : set1) {
-      if(set2.find(iter.first) == set2.end()) {
-        return false;
+    for(const auto &iter : set1) {
+      if(set2.find(iter) != set1.end()) {
+        return true;
       }
     }
-    return true;
+    return false;
   }
 
 }
